@@ -6,5 +6,5 @@ def connect(host = 'localhost', port = 5672, **kwargs):
     )
 
     connection = pika.BlockingConnection(parameters=parameters)
-    channel = connection.channel()
-    return channel
\ No newline at end of file
+    # channel = connection.channel()
+    return connection
\ No newline at end of file
