@@ -1,4 +1,7 @@
+from trending_bay_messaging.client import Client
+
 def consume(channel, callback, exchange = None ,**kwargs):
+    client = Client(channel=channel)
     if exchange is None:
         exchange = "DEFAULT_EXCHANGE"
     while True:
